summaryrefslogtreecommitdiff
path: root/sw/source/uibase/shells
diff options
context:
space:
mode:
authorMike Kaganski <mike.kaganski@collabora.com>2022-06-30 06:09:23 +0300
committerMike Kaganski <mike.kaganski@collabora.com>2022-07-28 07:37:31 +0200
commit30e08c83e502562966351f4236e9dd9230ffa435 (patch)
treec30f96ce2290e404f10e186f0229334b287544a7 /sw/source/uibase/shells
parent2fc16dc84d0b1b1bd7978a30e1b79ff3100fefdf (diff)
lok: Enable sidebar in Math
Change-Id: I1554a924eef0bfcaffa893057a37ef45321a0cf7 Reviewed-on: https://gerrit.libreoffice.org/c/core/+/137246 Tested-by: Jenkins Reviewed-by: Mike Kaganski <mike.kaganski@collabora.com>
Diffstat (limited to 'sw/source/uibase/shells')
-rw-r--r--sw/source/uibase/shells/olesh.cxx12
1 files changed, 6 insertions, 6 deletions
diff --git a/sw/source/uibase/shells/olesh.cxx b/sw/source/uibase/shells/olesh.cxx
index acddd3eb6975..28e8e153eeb1 100644
--- a/sw/source/uibase/shells/olesh.cxx
+++ b/sw/source/uibase/shells/olesh.cxx
@@ -34,11 +34,11 @@ using namespace sfx2::sidebar;
namespace {
-bool inChartContext(const SwView& rViewShell)
+bool inChartOrMathContext(const SwView& rViewShell)
{
SidebarController* pSidebar = SidebarController::GetSidebarControllerForView(&rViewShell);
if (pSidebar)
- return pSidebar->hasChartContextCurrently();
+ return pSidebar->hasChartOrMathContextCurrently();
return false;
}
@@ -56,11 +56,11 @@ void SwOleShell::InitInterface_Impl()
void SwOleShell::Activate(bool bMDI)
{
- if(!inChartContext(GetView()))
+ if(!inChartOrMathContext(GetView()))
SwFrameShell::Activate(bMDI);
else
{
// Avoid context changes for chart during activation / deactivation.
const bool bIsContextBroadcasterEnabled (SfxShell::SetContextBroadcasterEnabled(false));
SwFrameShell::Activate(bMDI);
@@ -71,11 +71,11 @@ void SwOleShell::Activate(bool bMDI)
void SwOleShell::Deactivate(bool bMDI)
{
- if(!inChartContext(GetView()))
+ if(!inChartOrMathContext(GetView()))
SwFrameShell::Deactivate(bMDI);
else
{
// Avoid context changes for chart during activation / deactivation.
const bool bIsContextBroadcasterEnabled (SfxShell::SetContextBroadcasterEnabled(false));
SwFrameShell::Deactivate(bMDI);
@@ -56,11 +56,11 @@ void SwOleShell::InitInterface_Impl()
else
{
- // Avoid context changes for chart during activation / deactivation.
+ // Avoid context changes for chart/math during activation / deactivation.
const bool bIsContextBroadcasterEnabled (SfxShell::SetContextBroadcasterEnabled(false));
SwFrameShell::Activate(bMDI);
@@ -71,11 +71,11 @@ void SwOleShell::Activate(bool bMDI)
else
{
- // Avoid context changes for chart during activation / deactivation.
+ // Avoid context changes for chart/math during activation / deactivation.
const bool bIsContextBroadcasterEnabled (SfxShell::SetContextBroadcasterEnabled(false));
SwFrameShell::Deactivate(bMDI);